::: inferno.datasets
    options:
        members:
        - MNIST
        - MNISTC
        - CIFAR10
        - CIFAR10C
        - CIFAR100
        - CIFAR100C
        - TinyImageNet
        - TinyImageNetC